summaryrefslogtreecommitdiff
path: root/libs
diff options
context:
space:
mode:
authorLen Ovens <len@ovenwerks.net>2018-11-12 21:40:29 -0800
committerLen Ovens <len@ovenwerks.net>2018-11-12 22:30:32 -0800
commitf27ca29d6c7e294a71c46d2e3390331aa72ad1d0 (patch)
tree48c85fa5e9c489c4435d634683d76b7ee6026f12 /libs
parente9013c0f99a3f16097800276241e8363fda33e8f (diff)
Changed send/deliver role "Personal" to "Foldback" so bus type can match
Diffstat (limited to 'libs')
-rw-r--r--libs/ardour/ardour/delivery.h4
-rw-r--r--libs/ardour/ardour/route.h2
-rw-r--r--libs/ardour/ardour/send.h2
-rw-r--r--libs/ardour/delivery.cc6
-rw-r--r--libs/ardour/enums.cc2
-rw-r--r--libs/ardour/route.cc14
-rw-r--r--libs/ardour/send.cc10
-rw-r--r--libs/surfaces/osc/osc.cc4
8 files changed, 22 insertions, 22 deletions
diff --git a/libs/ardour/ardour/route.h b/libs/ardour/ardour/route.h
index f9e0af30f3..24f3f998fc 100644
--- a/libs/ardour/ardour/route.h
+++ b/libs/ardour/ardour/route.h
@@ -412,7 +412,7 @@ public:
PBD::Signal1<void,void*> SelectedChanged;
int add_aux_send (boost::shared_ptr<Route>, boost::shared_ptr<Processor>);
- int add_personal_send (boost::shared_ptr<Route>);
+ int add_foldback_send (boost::shared_ptr<Route>);
void remove_aux_or_listen (boost::shared_ptr<Route>);
/**
diff --git a/libs/ardour/ardour/send.h b/libs/ardour/ardour/send.h
index 9423791d82..d357551cb5 100644
--- a/libs/ardour/ardour/send.h
+++ b/libs/ardour/ardour/send.h
@@ -43,7 +43,7 @@ public:
uint32_t bit_slot() const { return _bitslot; }
bool display_to_user() const;
- bool is_personal () const { return _role == Personal; }
+ bool is_foldback () const { return _role == Foldback; }
boost::shared_ptr<Amp> amp() const { return _amp; }
boost::shared_ptr<PeakMeter> meter() const { return _meter; }
diff --git a/libs/ardour/delivery.cc b/libs/ardour/delivery.cc
index f9db910288..d717197091 100644
--- a/libs/ardour/delivery.cc
+++ b/libs/ardour/delivery.cc
@@ -63,7 +63,7 @@ Delivery::Delivery (Session& s, boost::shared_ptr<IO> io, boost::shared_ptr<Pann
{
if (pannable) {
bool is_send = false;
- if (r & (Delivery::Send|Delivery::Aux|Delivery::Personal)) is_send = true;
+ if (r & (Delivery::Send|Delivery::Aux|Delivery::Foldback)) is_send = true;
_panshell = boost::shared_ptr<PannerShell>(new PannerShell (_name, _session, pannable, is_send));
}
@@ -87,7 +87,7 @@ Delivery::Delivery (Session& s, boost::shared_ptr<Pannable> pannable, boost::sha
{
if (pannable) {
bool is_send = false;
- if (r & (Delivery::Send|Delivery::Aux|Delivery::Personal)) is_send = true;
+ if (r & (Delivery::Send|Delivery::Aux|Delivery::Foldback)) is_send = true;
_panshell = boost::shared_ptr<PannerShell>(new PannerShell (_name, _session, pannable, is_send));
}
@@ -556,7 +556,7 @@ Delivery::target_gain ()
case Send:
case Insert:
case Aux:
- case Personal:
+ case Foldback:
if (_pre_fader) {
mp = MuteMaster::PreFader;
} else {
diff --git a/libs/ardour/enums.cc b/libs/ardour/enums.cc
index 4ff286a1d7..28c59af7db 100644
--- a/libs/ardour/enums.cc
+++ b/libs/ardour/enums.cc
@@ -656,7 +656,7 @@ setup_enum_writer ()
REGISTER_CLASS_ENUM (Delivery, Listen);
REGISTER_CLASS_ENUM (Delivery, Main);
REGISTER_CLASS_ENUM (Delivery, Aux);
- REGISTER_CLASS_ENUM (Delivery, Personal);
+ REGISTER_CLASS_ENUM (Delivery, Foldback);
REGISTER_BITS (_Delivery_Role);
REGISTER_CLASS_ENUM (MuteMaster, PreFader);
diff --git a/libs/ardour/route.cc b/libs/ardour/route.cc
index 70c79a061c..054c9567bc 100644
--- a/libs/ardour/route.cc
+++ b/libs/ardour/route.cc
@@ -3209,7 +3209,7 @@ Route::add_aux_send (boost::shared_ptr<Route> route, boost::shared_ptr<Processor
}
int
-Route::add_personal_send (boost::shared_ptr<Route> route)
+Route::add_foldback_send (boost::shared_ptr<Route> route)
{
assert (route != _session.monitor_out ());
boost::shared_ptr<Processor> before = before_processor_for_placement (PreFader);
@@ -3234,7 +3234,7 @@ Route::add_personal_send (boost::shared_ptr<Route> route)
{
Glib::Threads::Mutex::Lock lm (AudioEngine::instance()->process_lock ());
- listener.reset (new InternalSend (_session, _pannable, _mute_master, boost::dynamic_pointer_cast<ARDOUR::Route>(shared_from_this()), route, Delivery::Personal));
+ listener.reset (new InternalSend (_session, _pannable, _mute_master, boost::dynamic_pointer_cast<ARDOUR::Route>(shared_from_this()), route, Delivery::Foldback));
}
add_processor (listener, before);
@@ -4718,7 +4718,7 @@ Route::setup_invisible_processors ()
*/
ProcessorList new_processors;
- ProcessorList personal_sends;
+ ProcessorList foldback_sends;
ProcessorList::iterator dr;
ProcessorList::iterator dw;
@@ -4729,8 +4729,8 @@ Route::setup_invisible_processors ()
if ((*i)->display_to_user ()) {
new_processors.push_back (*i);
}
- else if (auxsnd && auxsnd->is_personal ()) {
- personal_sends.push_back (*i);
+ else if (auxsnd && auxsnd->is_foldback ()) {
+ foldback_sends.push_back (*i);
}
}
@@ -4783,9 +4783,9 @@ Route::setup_invisible_processors ()
new_processors.insert (meter_point, _meter);
}
- /* Personal Sends */
+ /* Foldback Sends */
- for (ProcessorList::iterator i = personal_sends.begin(); i != personal_sends.end(); ++i) {
+ for (ProcessorList::iterator i = foldback_sends.begin(); i != foldback_sends.end(); ++i) {
new_processors.insert (amp, (*i));
}
diff --git a/libs/ardour/send.cc b/libs/ardour/send.cc
index 1bf1dadf4b..a9b8f2b135 100644
--- a/libs/ardour/send.cc
+++ b/libs/ardour/send.cc
@@ -67,8 +67,8 @@ Send::name_and_id_new_send (Session& s, Role r, uint32_t& bitslot, bool ignore_b
return _("listen"); // no ports, no need for numbering
case Delivery::Send:
return string_compose (_("send %1"), (bitslot = s.next_send_id ()) + 1);
- case Delivery::Personal:
- return string_compose (_("personal %1"), (bitslot = s.next_aux_send_id ()) + 1);
+ case Delivery::Foldback:
+ return string_compose (_("foldback %1"), (bitslot = s.next_aux_send_id ()) + 1);
default:
fatal << string_compose (_("programming error: send created using role %1"), enum_2_string (r)) << endmsg;
abort(); /*NOTREACHED*/
@@ -297,7 +297,7 @@ Send::set_state (const XMLNode& node, int version)
*/
if ((prop = node.property ("bitslot")) == 0) {
- if (_role == Delivery::Aux || _role == Delivery::Personal) {
+ if (_role == Delivery::Aux || _role == Delivery::Foldback) {
_bitslot = _session.next_aux_send_id ();
} else if (_role == Delivery::Send) {
_bitslot = _session.next_send_id ();
@@ -306,7 +306,7 @@ Send::set_state (const XMLNode& node, int version)
_bitslot = 0;
}
} else {
- if (_role == Delivery::Aux || _role == Delivery::Personal) {
+ if (_role == Delivery::Aux || _role == Delivery::Foldback) {
_session.unmark_aux_send_id (_bitslot);
_bitslot = string_to<uint32_t>(prop->value());
_session.mark_aux_send_id (_bitslot);
@@ -451,7 +451,7 @@ Send::display_to_user () const
{
/* we ignore Deliver::_display_to_user */
- if (_role == Listen || _role == Personal) {
+ if (_role == Listen || _role == Foldback) {
/* don't make the monitor/control/listen send visible */
return false;
}
diff --git a/libs/surfaces/osc/osc.cc b/libs/surfaces/osc/osc.cc
index 24b7e76e43..691107f538 100644
--- a/libs/surfaces/osc/osc.cc
+++ b/libs/surfaces/osc/osc.cc
@@ -4318,7 +4318,7 @@ OSC::sel_new_personal_send (char *listener, lo_message msg)
bool s_only = true;
if (!rt->feeds (lsn_rt, &s_only)) {
// create send
- rt->add_personal_send (lsn_rt);
+ rt->add_foldback_send (lsn_rt);
//boost::shared_ptr<Send> snd = rt->internal_send_for (aux);
session->dirty ();
return 0;
@@ -6607,7 +6607,7 @@ OSC::cue_new_send (string rt_name, lo_message msg)
bool s_only = true;
if (!rt_send->feeds (aux, &s_only)) {
// create send
- rt_send->add_personal_send (aux);
+ rt_send->add_foldback_send (aux);
boost::shared_ptr<Send> snd = rt_send->internal_send_for (aux);
session->dirty ();
return 0;
diff --git a/libs/ardour/ardour/delivery.h b/libs/ardour/ardour/delivery.h
index 88db428600..63d423b8fb 100644
--- a/libs/ardour/ardour/delivery.h
+++ b/libs/ardour/ardour/delivery.h
@@ -49,8 +49,8 @@ public:
Listen = 0x8,
/* aux - internal send used to deliver to any bus, by user request */
Aux = 0x10,
- /* personal - internal send used only to deliver to a personal monitor bus */
- Personal = 0x20
+ /* foldback - internal send used only to deliver to a personal monitor bus */
+ Foldback = 0x20
};
static bool role_requires_output_ports (Role r) { return r == Main || r == Send || r == Insert; }